package net.sf.doolin.context.spring;

import java.util.HashSet;
import java.util.Set;

/**
 * Management of custom namespaces.
 * 
 * Custom namespace handlers must register their namespace using this class so
 * that their parsing is automatically realized when their elements are nested
 * in other custom elements.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class CustomNamespaces {

	private static Set<String> namespaces = new HashSet<String>();

	private CustomNamespaces() {
	}

	/**
	 * Registers a new custom namespace
	 * 
	 * @param ns
	 *            Namespace URI
	 */
	public static synchronized void addCustomNamespace(String ns) {
		namespaces.add(ns);
	}

	/**
	 * Checks if the given <code>ns</code> is a registered custom namespace.
	 * 
	 * @param ns
	 *            Namespace URI
	 * @return <code>true</code> if <code>ns</code> has been registered as a
	 *         custom namespace.
	 */
	public static synchronized boolean isCustomNamespace(String ns) {
		return namespaces.contains(ns);
	}

}
