package net.sf.doolin.context.util;

import org.springframework.beans.factory.xml.XmlBeanDefinitionReader;
import org.springframework.context.ApplicationContext;
import org.springframework.context.support.ClassPathXmlApplicationContext;

/**
 * Utilities for dealing with Spring context.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class ContextUtils {

	/**
	 * System property (<code>Context.validate</code>) that enables or not the
	 * validation. By default, the validation is disabled.
	 */
	public static final String VALIDATION = "Context.validate";

	private ContextUtils() {
	}

	/**
	 * Loads an application context.
	 * 
	 * @param contextPaths
	 *            List of context to load
	 * @return Application context
	 * 
	 * @see ClassPathXmlApplicationContext#ClassPathXmlApplicationContext(String[])
	 */
	public static ApplicationContext load(String... contextPaths) {
		if (Boolean.getBoolean(VALIDATION)) {
			// Validating context
			return new ClassPathXmlApplicationContext(contextPaths) {

				@Override
				protected void initBeanDefinitionReader(
						XmlBeanDefinitionReader beanDefinitionReader) {
					super.initBeanDefinitionReader(beanDefinitionReader);
					// Validation
					boolean validate = Boolean.getBoolean(VALIDATION);
					if (!validate) {
						beanDefinitionReader
								.setValidationMode(XmlBeanDefinitionReader.VALIDATION_NONE);
						beanDefinitionReader.setNamespaceAware(true);
					}
				}

			};
		} else {
			// Non validating context
			return new ClassPathXmlApplicationContext(contextPaths);
		}
	}

}
